@@ -39,6 +39,8 @@ if TYPE_CHECKING:
     HTTPProtocol: TypeAlias = "type[HttpToolsProtocol | H11Protocol]"
     WSProtocol: TypeAlias = "type[WebSocketProtocol | _WSProtocol]"
 
+pytestmark = pytest.mark.anyio
+
 
 WEBSOCKET_PROTOCOLS = WS_PROTOCOLS.keys()
 
@@ -57,9 +59,7 @@ SIMPLE_POST_REQUEST = b"\r\n".join(
     ]
 )
 
-CONNECTION_CLOSE_REQUEST = b"\r\n".join(
-    [b"GET / HTTP/1.1", b"Host: example.org", b"Connection: close", b"", b""]
-)
+CONNECTION_CLOSE_REQUEST = b"\r\n".join([b"GET / HTTP/1.1", b"Host: example.org", b"Connection: close", b"", b""])
 
 LARGE_POST_REQUEST = b"\r\n".join(
     [
@@ -87,9 +87,7 @@ FINISH_POST_REQUEST = b'{"hello": "world"}'
 
 HTTP10_GET_REQUEST = b"\r\n".join([b"GET / HTTP/1.0", b"Host: example.org", b"", b""])
 
-GET_REQUEST_WITH_RAW_PATH = b"\r\n".join(
-    [b"GET /one%2Ftwo HTTP/1.1", b"Host: example.org", b"", b""]
-)
+GET_REQUEST_WITH_RAW_PATH = b"\r\n".join([b"GET /one%2Ftwo HTTP/1.1", b"Host: example.org", b"", b""])
 
 UPGRADE_REQUEST = b"\r\n".join(
     [
@@ -243,7 +241,6 @@ def get_connected_protocol(
     return protocol
 
 
-@pytest.mark.anyio
 async def test_get_request(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
@@ -254,13 +251,29 @@ async def test_get_request(http_protocol_cls: HTTPProtocol):
     assert b"Hello, world" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
+@pytest.mark.parametrize(
+    "char",
+    [
+        pytest.param("c", id="allow_ascii_letter"),
+        pytest.param("\t", id="allow_tab"),
+        pytest.param(" ", id="allow_space"),
+        pytest.param("µ", id="allow_non_ascii_char"),
+    ],
+)
+async def test_header_value_allowed_characters(http_protocol_cls: HTTPProtocol, char: str):
+    app = Response("Hello, world", media_type="text/plain", headers={"key": f"<{char}>"})
+    protocol = get_connected_protocol(app, http_protocol_cls)
+    protocol.data_received(SIMPLE_GET_REQUEST)
+    await protocol.loop.run_one()
+    assert b"HTTP/1.1 200 OK" in protocol.transport.buffer
+    assert (b"\r\nkey: <" + char.encode() + b">\r\n") in protocol.transport.buffer
+    assert b"Hello, world" in protocol.transport.buffer
+
+
 @pytest.mark.parametrize("path", ["/", "/?foo", "/?foo=bar", "/?foo=bar&baz=1"])
-async def test_request_logging(
-    path: str, http_protocol_cls: HTTPProtocol, caplog: pytest.LogCaptureFixture
-):
+async def test_request_logging(path: str, http_protocol_cls: HTTPProtocol, caplog: pytest.LogCaptureFixture):
     get_request_with_query_string = b"\r\n".join(
-        ["GET {} HTTP/1.1".format(path).encode("ascii"), b"Host: example.org", b"", b""]
+        [f"GET {path} HTTP/1.1".encode("ascii"), b"Host: example.org", b"", b""]
     )
     caplog.set_level(logging.INFO, logger="uvicorn.access")
     logging.getLogger("uvicorn.access").propagate = True
@@ -270,10 +283,9 @@ async def test_request_logging(
     protocol = get_connected_protocol(app, http_protocol_cls, log_config=None)
     protocol.data_received(get_request_with_query_string)
     await protocol.loop.run_one()
-    assert '"GET {} HTTP/1.1" 200'.format(path) in caplog.records[0].message
+    assert f'"GET {path} HTTP/1.1" 200' in caplog.records[0].message
 
 
-@pytest.mark.anyio
 async def test_head_request(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
@@ -284,7 +296,6 @@ async def test_head_request(http_protocol_cls: HTTPProtocol):
     assert b"Hello, world" not in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_post_request(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         body = b""
@@ -304,7 +315,6 @@ async def test_post_request(http_protocol_cls: HTTPProtocol):
     assert b'Body: {"hello": "world"}' in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_keepalive(http_protocol_cls: HTTPProtocol):
     app = Response(b"", status_code=204)
 
@@ -316,7 +326,6 @@ async def test_keepalive(http_protocol_cls: HTTPProtocol):
     assert not protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
 async def test_keepalive_timeout(http_protocol_cls: HTTPProtocol):
     app = Response(b"", status_code=204)
 
@@ -331,7 +340,6 @@ async def test_keepalive_timeout(http_protocol_cls: HTTPProtocol):
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
 async def test_keepalive_timeout_with_pipelined_requests(
     http_protocol_cls: HTTPProtocol,
 ):
@@ -357,7 +365,6 @@ async def test_keepalive_timeout_with_pipelined_requests(
     assert protocol.timeout_keep_alive_task is not None
 
 
-@pytest.mark.anyio
 async def test_close(http_protocol_cls: HTTPProtocol):
     app = Response(b"", status_code=204, headers={"connection": "close"})
 
@@ -368,13 +375,8 @@ async def test_close(http_protocol_cls: HTTPProtocol):
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_chunked_encoding(
-    http_protocol_cls: HTTPProtocol,
-):
-    app = Response(
-        b"Hello, world!", status_code=200, headers={"transfer-encoding": "chunked"}
-    )
+async def test_chunked_encoding(http_protocol_cls: HTTPProtocol):
+    app = Response(b"Hello, world!", status_code=200, headers={"transfer-encoding": "chunked"})
 
     protocol = get_connected_protocol(app, http_protocol_cls)
     protocol.data_received(SIMPLE_GET_REQUEST)
@@ -384,13 +386,8 @@ async def test_chunked_encoding(
     assert not protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_chunked_encoding_empty_body(
-    http_protocol_cls: HTTPProtocol,
-):
-    app = Response(
-        b"Hello, world!", status_code=200, headers={"transfer-encoding": "chunked"}
-    )
+async def test_chunked_encoding_empty_body(http_protocol_cls: HTTPProtocol):
+    app = Response(b"Hello, world!", status_code=200, headers={"transfer-encoding": "chunked"})
 
     protocol = get_connected_protocol(app, http_protocol_cls)
     protocol.data_received(SIMPLE_GET_REQUEST)
@@ -400,13 +397,10 @@ async def test_chunked_encoding_empty_body(
     assert not protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
 async def test_chunked_encoding_head_request(
     http_protocol_cls: HTTPProtocol,
 ):
-    app = Response(
-        b"Hello, world!", status_code=200, headers={"transfer-encoding": "chunked"}
-    )
+    app = Response(b"Hello, world!", status_code=200, headers={"transfer-encoding": "chunked"})
 
     protocol = get_connected_protocol(app, http_protocol_cls)
     protocol.data_received(SIMPLE_HEAD_REQUEST)
@@ -415,10 +409,7 @@ async def test_chunked_encoding_head_request(
     assert not protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_pipelined_requests(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_pipelined_requests(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
     protocol = get_connected_protocol(app, http_protocol_cls)
@@ -439,10 +430,7 @@ async def test_pipelined_requests(
     protocol.transport.clear_buffer()
 
 
-@pytest.mark.anyio
-async def test_undersized_request(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_undersized_request(http_protocol_cls: HTTPProtocol):
     app = Response(b"xxx", headers={"content-length": "10"})
 
     protocol = get_connected_protocol(app, http_protocol_cls)
@@ -451,10 +439,7 @@ async def test_undersized_request(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_oversized_request(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_oversized_request(http_protocol_cls: HTTPProtocol):
     app = Response(b"xxx" * 20, headers={"content-length": "10"})
 
     protocol = get_connected_protocol(app, http_protocol_cls)
@@ -463,10 +448,7 @@ async def test_oversized_request(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_large_post_request(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_large_post_request(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
     protocol = get_connected_protocol(app, http_protocol_cls)
@@ -476,7 +458,6 @@ async def test_large_post_request(
     assert not protocol.transport.read_paused
 
 
-@pytest.mark.anyio
 async def test_invalid_http(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
@@ -485,10 +466,7 @@ async def test_invalid_http(http_protocol_cls: HTTPProtocol):
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_app_exception(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_app_exception(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         raise Exception()
 
@@ -499,10 +477,7 @@ async def test_app_exception(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_exception_during_response(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_exception_during_response(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         await send({"type": "http.response.start", "status": 200})
         await send({"type": "http.response.body", "body": b"1", "more_body": True})
@@ -515,12 +490,8 @@ async def test_exception_during_response(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_no_response_returned(
-    http_protocol_cls: HTTPProtocol,
-):
-    async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
-        ...
+async def test_no_response_returned(http_protocol_cls: HTTPProtocol):
+    async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable): ...
 
     protocol = get_connected_protocol(app, http_protocol_cls)
     protocol.data_received(SIMPLE_GET_REQUEST)
@@ -529,10 +500,7 @@ async def test_no_response_returned(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_partial_response_returned(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_partial_response_returned(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         await send({"type": "http.response.start", "status": 200})
 
@@ -543,10 +511,18 @@ async def test_partial_response_returned(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_duplicate_start_message(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_response_header_splitting(http_protocol_cls: HTTPProtocol):
+    app = Response(b"", headers={"key": "value\r\nCookie: smuggled=value"})
+
+    protocol = get_connected_protocol(app, http_protocol_cls)
+    protocol.data_received(SIMPLE_GET_REQUEST)
+    await protocol.loop.run_one()
+    assert b"HTTP/1.1 500 Internal Server Error" not in protocol.transport.buffer
+    assert b"\r\nCookie: smuggled=value\r\n" not in protocol.transport.buffer
+    assert protocol.transport.is_closing()
+
+
+async def test_duplicate_start_message(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         await send({"type": "http.response.start", "status": 200})
         await send({"type": "http.response.start", "status": 200})
@@ -558,10 +534,7 @@ async def test_duplicate_start_message(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_missing_start_message(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_missing_start_message(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         await send({"type": "http.response.body", "body": b""})
 
@@ -572,10 +545,7 @@ async def test_missing_start_message(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_message_after_body_complete(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_message_after_body_complete(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         await send({"type": "http.response.start", "status": 200})
         await send({"type": "http.response.body", "body": b""})
@@ -588,10 +558,7 @@ async def test_message_after_body_complete(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_value_returned(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_value_returned(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         await send({"type": "http.response.start", "status": 200})
         await send({"type": "http.response.body", "body": b""})
@@ -604,10 +571,7 @@ async def test_value_returned(
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_early_disconnect(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_early_disconnect(http_protocol_cls: HTTPProtocol):
     got_disconnect_event = False
 
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
@@ -628,10 +592,7 @@ async def test_early_disconnect(
     assert got_disconnect_event
 
 
-@pytest.mark.anyio
-async def test_early_response(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_early_response(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
     protocol = get_connected_protocol(app, http_protocol_cls)
@@ -642,10 +603,7 @@ async def test_early_response(
     assert not protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
-async def test_read_after_response(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_read_after_response(http_protocol_cls: HTTPProtocol):
     message_after_response = None
 
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
@@ -662,10 +620,7 @@ async def test_read_after_response(
     assert message_after_response == {"type": "http.disconnect"}
 
 
-@pytest.mark.anyio
-async def test_http10_request(
-    http_protocol_cls: HTTPProtocol,
-):
+async def test_http10_request(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         assert scope["type"] == "http"
         content = "Version: %s" % scope["http_version"]
@@ -679,15 +634,12 @@ async def test_http10_request(
     assert b"Version: 1.0" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_root_path(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         assert scope["type"] == "http"
         root_path = scope.get("root_path", "")
         path = scope["path"]
-        response = Response(
-            f"root_path={root_path} path={path}", media_type="text/plain"
-        )
+        response = Response(f"root_path={root_path} path={path}", media_type="text/plain")
         await response(scope, receive, send)
 
     protocol = get_connected_protocol(app, http_protocol_cls, root_path="/app")
@@ -697,7 +649,6 @@ async def test_root_path(http_protocol_cls: HTTPProtocol):
     assert b"root_path=/app path=/app/" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_raw_path(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         assert scope["type"] == "http"
@@ -715,17 +666,27 @@ async def test_raw_path(http_protocol_cls: HTTPProtocol):
     assert b"Done" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_max_concurrency(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
     protocol = get_connected_protocol(app, http_protocol_cls, limit_concurrency=1)
     protocol.data_received(SIMPLE_GET_REQUEST)
     await protocol.loop.run_one()
-    assert b"HTTP/1.1 503 Service Unavailable" in protocol.transport.buffer
+    assert (
+        b"\r\n".join(
+            [
+                b"HTTP/1.1 503 Service Unavailable",
+                b"content-type: text/plain; charset=utf-8",
+                b"content-length: 19",
+                b"connection: close",
+                b"",
+                b"Service Unavailable",
+            ]
+        )
+        == protocol.transport.buffer
+    )
 
 
-@pytest.mark.anyio
 async def test_shutdown_during_request(http_protocol_cls: HTTPProtocol):
     app = Response(b"", status_code=204)
 
@@ -737,7 +698,6 @@ async def test_shutdown_during_request(http_protocol_cls: HTTPProtocol):
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
 async def test_shutdown_during_idle(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
@@ -747,7 +707,6 @@ async def test_shutdown_during_idle(http_protocol_cls: HTTPProtocol):
     assert protocol.transport.is_closing()
 
 
-@pytest.mark.anyio
 async def test_100_continue_sent_when_body_consumed(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         body = b""
@@ -779,7 +738,6 @@ async def test_100_continue_sent_when_body_consumed(http_protocol_cls: HTTPProto
     assert b'Body: {"hello": "world"}' in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_100_continue_not_sent_when_body_not_consumed(
     http_protocol_cls: HTTPProtocol,
 ):
@@ -803,7 +761,6 @@ async def test_100_continue_not_sent_when_body_not_consumed(
     assert b"HTTP/1.1 204 No Content" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_supported_upgrade_request(http_protocol_cls: HTTPProtocol):
     pytest.importorskip("wsproto")
 
@@ -814,7 +771,6 @@ async def test_supported_upgrade_request(http_protocol_cls: HTTPProtocol):
     assert b"HTTP/1.1 426 " in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_unsupported_ws_upgrade_request(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
@@ -825,7 +781,6 @@ async def test_unsupported_ws_upgrade_request(http_protocol_cls: HTTPProtocol):
     assert b"Hello, world" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_unsupported_ws_upgrade_request_warn_on_auto(
     caplog: pytest.LogCaptureFixture, http_protocol_cls: HTTPProtocol
 ):
@@ -837,21 +792,13 @@ async def test_unsupported_ws_upgrade_request_warn_on_auto(
     await protocol.loop.run_one()
     assert b"HTTP/1.1 200 OK" in protocol.transport.buffer
     assert b"Hello, world" in protocol.transport.buffer
-    warnings = [
-        record.msg
-        for record in filter(
-            lambda record: record.levelname == "WARNING", caplog.records
-        )
-    ]
+    warnings = [record.msg for record in filter(lambda record: record.levelname == "WARNING", caplog.records)]
     assert "Unsupported upgrade request." in warnings
     msg = "No supported WebSocket library detected. Please use \"pip install 'uvicorn[standard]'\", or install 'websockets' or 'wsproto' manually."  # noqa: E501
     assert msg in warnings
 
 
-@pytest.mark.anyio
-async def test_http2_upgrade_request(
-    http_protocol_cls: HTTPProtocol, ws_protocol_cls: WSProtocol
-):
+async def test_http2_upgrade_request(http_protocol_cls: HTTPProtocol, ws_protocol_cls: WSProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
     protocol = get_connected_protocol(app, http_protocol_cls, ws=ws_protocol_cls)
@@ -872,12 +819,11 @@ def asgi2app(scope: Scope):
     return asgi
 
 
-@pytest.mark.anyio
 @pytest.mark.parametrize(
     "asgi2or3_app, expected_scopes",
     [
-        (asgi3app, {"version": "3.0", "spec_version": "2.3"}),
-        (asgi2app, {"version": "2.0", "spec_version": "2.3"}),
+        (asgi3app, {"version": "3.0", "spec_version": "2.4"}),
+        (asgi2app, {"version": "2.0", "spec_version": "2.4"}),
     ],
 )
 async def test_scopes(
@@ -891,7 +837,6 @@ async def test_scopes(
     assert expected_scopes == protocol.scope.get("asgi")
 
 
-@pytest.mark.anyio
 @pytest.mark.parametrize(
     "request_line",
     [
@@ -931,9 +876,7 @@ def test_fragmentation(unused_tcp_port: int):
     def send_fragmented_req(path: str):
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         sock.connect(("127.0.0.1", unused_tcp_port))
-        d = (
-            f"GET {path} HTTP/1.1\r\n" "Host: localhost\r\n" "Connection: close\r\n\r\n"
-        ).encode()
+        d = (f"GET {path} HTTP/1.1\r\n" "Host: localhost\r\n" "Connection: close\r\n\r\n").encode()
         split = len(path) // 2
         sock.sendall(d[:split])
         time.sleep(0.01)
@@ -963,7 +906,6 @@ def test_fragmentation(unused_tcp_port: int):
     t.join()
 
 
-@pytest.mark.anyio
 async def test_huge_headers_h11protocol_failure():
     app = Response("Hello, world", media_type="text/plain")
 
@@ -976,7 +918,6 @@ async def test_huge_headers_h11protocol_failure():
     assert b"Invalid HTTP request received." in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 @skip_if_no_httptools
 async def test_huge_headers_httptools_will_pass():
     app = Response("Hello, world", media_type="text/plain")
@@ -991,13 +932,10 @@ async def test_huge_headers_httptools_will_pass():
     assert b"Hello, world" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_huge_headers_h11protocol_failure_with_setting():
     app = Response("Hello, world", media_type="text/plain")
 
-    protocol = get_connected_protocol(
-        app, H11Protocol, h11_max_incomplete_event_size=20 * 1024
-    )
+    protocol = get_connected_protocol(app, H11Protocol, h11_max_incomplete_event_size=20 * 1024)
     # Huge headers make h11 fail in it's default config
     # h11 sends back a 400 in this case
     protocol.data_received(GET_REQUEST_HUGE_HEADERS[0])
@@ -1006,7 +944,6 @@ async def test_huge_headers_h11protocol_failure_with_setting():
     assert b"Invalid HTTP request received." in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 @skip_if_no_httptools
 async def test_huge_headers_httptools():
     app = Response("Hello, world", media_type="text/plain")
@@ -1021,13 +958,10 @@ async def test_huge_headers_httptools():
     assert b"Hello, world" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_huge_headers_h11_max_incomplete():
     app = Response("Hello, world", media_type="text/plain")
 
-    protocol = get_connected_protocol(
-        app, H11Protocol, h11_max_incomplete_event_size=64 * 1024
-    )
+    protocol = get_connected_protocol(app, H11Protocol, h11_max_incomplete_event_size=64 * 1024)
     protocol.data_received(GET_REQUEST_HUGE_HEADERS[0])
     protocol.data_received(GET_REQUEST_HUGE_HEADERS[1])
     await protocol.loop.run_one()
@@ -1035,7 +969,6 @@ async def test_huge_headers_h11_max_incomplete():
     assert b"Hello, world" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_return_close_header(http_protocol_cls: HTTPProtocol):
     app = Response("Hello, world", media_type="text/plain")
 
@@ -1050,7 +983,6 @@ async def test_return_close_header(http_protocol_cls: HTTPProtocol):
     assert b"connection: close" in protocol.transport.buffer.lower()
 
 
-@pytest.mark.anyio
 async def test_iterator_headers(http_protocol_cls: HTTPProtocol):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         headers = iter([(b"x-test-header", b"test value")])
@@ -1063,7 +995,6 @@ async def test_iterator_headers(http_protocol_cls: HTTPProtocol):
     assert b"x-test-header: test value" in protocol.transport.buffer
 
 
-@pytest.mark.anyio
 async def test_lifespan_state(http_protocol_cls: HTTPProtocol):
     expected_states = [{"a": 123, "b": [1]}, {"a": 123, "b": [1, 2]}]
 
