@@ -48,11 +48,11 @@ if typing.TYPE_CHECKING:
     HTTPProtocol: TypeAlias = "type[H11Protocol | HttpToolsProtocol]"
     WSProtocol: TypeAlias = "type[_WSProtocol | WebSocketProtocol]"
 
+pytestmark = pytest.mark.anyio
+
 
 class WebSocketResponse:
-    def __init__(
-        self, scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable
-    ):
+    def __init__(self, scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         self.scope = scope
         self.receive = receive
         self.send = send
@@ -86,16 +86,11 @@ async def wsresponse(url):
         return await client.get(url, headers=headers)
 
 
-@pytest.mark.anyio
-async def test_invalid_upgrade(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_invalid_upgrade(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     def app(scope: Scope):
         return None
 
-    config = Config(
-        app=app, ws=ws_protocol_cls, http=http_protocol_cls, port=unused_tcp_port
-    )
+    config = Config(app=app, ws=ws_protocol_cls, http=http_protocol_cls, port=unused_tcp_port)
     async with run_server(config):
         async with httpx.AsyncClient() as client:
             response = await client.get(
@@ -117,18 +112,13 @@ async def test_invalid_upgrade(
                     "missing sec-websocket-key header",
                     "missing sec-websocket-version header",  # websockets
                     "missing or empty sec-websocket-key header",  # wsproto
-                    "failed to open a websocket connection: missing "
-                    "sec-websocket-key header",
-                    "failed to open a websocket connection: missing or empty "
-                    "sec-websocket-key header",
+                    "failed to open a websocket connection: missing " "sec-websocket-key header",
+                    "failed to open a websocket connection: missing or empty " "sec-websocket-key header",
                 ]
             )
 
 
-@pytest.mark.anyio
-async def test_accept_connection(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_accept_connection(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     class App(WebSocketResponse):
         async def websocket_connect(self, message):
             await self.send({"type": "websocket.accept"})
@@ -149,10 +139,7 @@ async def test_accept_connection(
         assert is_open
 
 
-@pytest.mark.anyio
-async def test_shutdown(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_shutdown(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     class App(WebSocketResponse):
         async def websocket_connect(self, message):
             await self.send({"type": "websocket.accept"})
@@ -170,7 +157,6 @@ async def test_shutdown(
             await server.shutdown()
 
 
-@pytest.mark.anyio
 async def test_supports_permessage_deflate_extension(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -180,9 +166,7 @@ async def test_supports_permessage_deflate_extension(
 
     async def open_connection(url):
         extension_factories = [ClientPerMessageDeflateFactory()]
-        async with websockets.client.connect(
-            url, extensions=extension_factories
-        ) as websocket:
+        async with websockets.client.connect(url, extensions=extension_factories) as websocket:
             return [extension.name for extension in websocket.extensions]
 
     config = Config(
@@ -197,7 +181,6 @@ async def test_supports_permessage_deflate_extension(
         assert "permessage-deflate" in extension_names
 
 
-@pytest.mark.anyio
 async def test_can_disable_permessage_deflate_extension(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -209,9 +192,7 @@ async def test_can_disable_permessage_deflate_extension(
         # enable per-message deflate on the client, so that we can check the server
         # won't support it when it's disabled.
         extension_factories = [ClientPerMessageDeflateFactory()]
-        async with websockets.client.connect(
-            url, extensions=extension_factories
-        ) as websocket:
+        async with websockets.client.connect(url, extensions=extension_factories) as websocket:
             return [extension.name for extension in websocket.extensions]
 
     config = Config(
@@ -227,10 +208,7 @@ async def test_can_disable_permessage_deflate_extension(
         assert "permessage-deflate" not in extension_names
 
 
-@pytest.mark.anyio
-async def test_close_connection(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_close_connection(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     class App(WebSocketResponse):
         async def websocket_connect(self, message):
             await self.send({"type": "websocket.close"})
@@ -254,10 +232,7 @@ async def test_close_connection(
         assert not is_open
 
 
-@pytest.mark.anyio
-async def test_headers(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_headers(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     class App(WebSocketResponse):
         async def websocket_connect(self, message):
             headers = self.scope.get("headers")
@@ -267,9 +242,7 @@ async def test_headers(
             await self.send({"type": "websocket.accept"})
 
     async def open_connection(url: str):
-        async with websockets.client.connect(
-            url, extra_headers=[("username", "abraão")]
-        ) as websocket:
+        async with websockets.client.connect(url, extra_headers=[("username", "abraão")]) as websocket:
             return websocket.open
 
     config = Config(
@@ -284,15 +257,10 @@ async def test_headers(
         assert is_open
 
 
-@pytest.mark.anyio
-async def test_extra_headers(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_extra_headers(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     class App(WebSocketResponse):
         async def websocket_connect(self, message):
-            await self.send(
-                {"type": "websocket.accept", "headers": [(b"extra", b"header")]}
-            )
+            await self.send({"type": "websocket.accept", "headers": [(b"extra", b"header")]})
 
     async def open_connection(url: str):
         async with websockets.client.connect(url) as websocket:
@@ -310,10 +278,7 @@ async def test_extra_headers(
         assert extra_headers.get("extra") == "header"
 
 
-@pytest.mark.anyio
-async def test_path_and_raw_path(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_path_and_raw_path(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     class App(WebSocketResponse):
         async def websocket_connect(self, message):
             path = self.scope.get("path")
@@ -338,7 +303,6 @@ async def test_path_and_raw_path(
         assert is_open
 
 
-@pytest.mark.anyio
 async def test_send_text_data_to_client(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -363,7 +327,6 @@ async def test_send_text_data_to_client(
         assert data == "123"
 
 
-@pytest.mark.anyio
 async def test_send_binary_data_to_client(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -388,7 +351,6 @@ async def test_send_binary_data_to_client(
         assert data == b"123"
 
 
-@pytest.mark.anyio
 async def test_send_and_close_connection(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -421,7 +383,6 @@ async def test_send_and_close_connection(
         assert not is_open
 
 
-@pytest.mark.anyio
 async def test_send_text_data_to_server(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -450,7 +411,6 @@ async def test_send_text_data_to_server(
         assert data == "abc"
 
 
-@pytest.mark.anyio
 async def test_send_binary_data_to_server(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -479,7 +439,6 @@ async def test_send_binary_data_to_server(
         assert data == b"abc"
 
 
-@pytest.mark.anyio
 async def test_send_after_protocol_close(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -514,10 +473,7 @@ async def test_send_after_protocol_close(
         assert not is_open
 
 
-@pytest.mark.anyio
-async def test_missing_handshake(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_missing_handshake(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         pass
 
@@ -537,7 +493,6 @@ async def test_missing_handshake(
         assert exc_info.value.status_code == 500
 
 
-@pytest.mark.anyio
 async def test_send_before_handshake(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -560,10 +515,7 @@ async def test_send_before_handshake(
         assert exc_info.value.status_code == 500
 
 
-@pytest.mark.anyio
-async def test_duplicate_handshake(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_duplicate_handshake(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         await send({"type": "websocket.accept"})
         await send({"type": "websocket.accept"})
@@ -585,10 +537,7 @@ async def test_duplicate_handshake(
         assert exc_info.value.code == 1006
 
 
-@pytest.mark.anyio
-async def test_asgi_return_value(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_asgi_return_value(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     """
     The ASGI callable should return 'None'. If it doesn't, make sure that
     the connection is closed with an error condition.
@@ -615,7 +564,6 @@ async def test_asgi_return_value(
         assert exc_info.value.code == 1006
 
 
-@pytest.mark.anyio
 @pytest.mark.parametrize("code", [None, 1000, 1001])
 @pytest.mark.parametrize(
     "reason",
@@ -667,11 +615,11 @@ async def test_app_close(
         assert exc_info.value.reason == (reason or "")
 
 
-@pytest.mark.anyio
-async def test_client_close(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_client_close(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
+    disconnect_message: WebSocketDisconnectEvent | None = None
+
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
+        nonlocal disconnect_message
         while True:
             message = await receive()
             if message["type"] == "websocket.connect":
@@ -679,12 +627,14 @@ async def test_client_close(
             elif message["type"] == "websocket.receive":
                 pass
             elif message["type"] == "websocket.disconnect":
+                disconnect_message = message
                 break
 
     async def websocket_session(url: str):
         async with websockets.client.connect(url) as websocket:
             await websocket.ping()
             await websocket.send("abc")
+            await websocket.close(code=1001, reason="custom reason")
 
     config = Config(
         app=app,
@@ -696,8 +646,9 @@ async def test_client_close(
     async with run_server(config):
         await websocket_session(f"ws://127.0.0.1:{unused_tcp_port}")
 
+    assert disconnect_message == {"type": "websocket.disconnect", "code": 1001, "reason": "custom reason"}
+
 
-@pytest.mark.anyio
 async def test_client_connection_lost(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -723,9 +674,7 @@ async def test_client_connection_lost(
         port=unused_tcp_port,
     )
     async with run_server(config):
-        async with websockets.client.connect(
-            f"ws://127.0.0.1:{unused_tcp_port}"
-        ) as websocket:
+        async with websockets.client.connect(f"ws://127.0.0.1:{unused_tcp_port}") as websocket:
             websocket.transport.close()
             await asyncio.sleep(0.1)
             got_disconnect_event_before_shutdown = got_disconnect_event
@@ -733,7 +682,6 @@ async def test_client_connection_lost(
     assert got_disconnect_event_before_shutdown is True
 
 
-@pytest.mark.anyio
 async def test_client_connection_lost_on_send(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -748,7 +696,7 @@ async def test_client_connection_lost_on_send(
         try:
             await disconnect.wait()
             await send({"type": "websocket.send", "text": "123"})
-        except IOError:
+        except OSError:
             got_disconnect_event = True
 
     config = Config(
@@ -767,7 +715,6 @@ async def test_client_connection_lost_on_send(
     assert got_disconnect_event is True
 
 
-@pytest.mark.anyio
 async def test_connection_lost_before_handshake_complete(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -781,7 +728,7 @@ async def test_connection_lost_before_handshake_complete(
             await send_accept_task.wait()
         disconnect_message = await receive()  # type: ignore
 
-    response: typing.Optional[httpx.Response] = None
+    response: httpx.Response | None = None
 
     async def websocket_session(uri: str):
         nonlocal response
@@ -804,9 +751,7 @@ async def test_connection_lost_before_handshake_complete(
         port=unused_tcp_port,
     )
     async with run_server(config):
-        task = asyncio.create_task(
-            websocket_session(f"ws://127.0.0.1:{unused_tcp_port}")
-        )
+        task = asyncio.create_task(websocket_session(f"ws://127.0.0.1:{unused_tcp_port}"))
         await asyncio.sleep(0.1)
         send_accept_task.set()
         await asyncio.sleep(0.1)
@@ -818,7 +763,6 @@ async def test_connection_lost_before_handshake_complete(
     await task
 
 
-@pytest.mark.anyio
 async def test_send_close_on_server_shutdown(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -835,7 +779,7 @@ async def test_send_close_on_server_shutdown(
                 disconnect_message = message
                 break
 
-    websocket: typing.Optional[websockets.client.WebSocketClientProtocol] = None
+    websocket: websockets.client.WebSocketClientProtocol | None = None
 
     async def websocket_session(uri: str):
         nonlocal websocket
@@ -851,9 +795,7 @@ async def test_send_close_on_server_shutdown(
         port=unused_tcp_port,
     )
     async with run_server(config):
-        task = asyncio.create_task(
-            websocket_session(f"ws://127.0.0.1:{unused_tcp_port}")
-        )
+        task = asyncio.create_task(websocket_session(f"ws://127.0.0.1:{unused_tcp_port}"))
         await asyncio.sleep(0.1)
         disconnect_message_before_shutdown = disconnect_message
     server_shutdown_event.set()
@@ -865,7 +807,6 @@ async def test_send_close_on_server_shutdown(
     task.cancel()
 
 
-@pytest.mark.anyio
 @pytest.mark.parametrize("subprotocol", ["proto1", "proto2"])
 async def test_subprotocols(
     ws_protocol_cls: WSProtocol,
@@ -891,9 +832,7 @@ async def test_subprotocols(
         port=unused_tcp_port,
     )
     async with run_server(config):
-        accepted_subprotocol = await get_subprotocol(
-            f"ws://127.0.0.1:{unused_tcp_port}"
-        )
+        accepted_subprotocol = await get_subprotocol(f"ws://127.0.0.1:{unused_tcp_port}")
         assert accepted_subprotocol == subprotocol
 
 
@@ -901,7 +840,6 @@ MAX_WS_BYTES = 1024 * 1024 * 16
 MAX_WS_BYTES_PLUS1 = MAX_WS_BYTES + 1
 
 
-@pytest.mark.anyio
 @pytest.mark.parametrize(
     "client_size_sent, server_size_max, expected_result",
     [
@@ -955,7 +893,6 @@ async def test_send_binary_data_to_server_bigger_than_default_on_websockets(
             assert e.value.code == expected_result
 
 
-@pytest.mark.anyio
 async def test_server_reject_connection(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -996,7 +933,6 @@ async def test_server_reject_connection(
     assert disconnected_message == {"type": "websocket.disconnect", "code": 1006}
 
 
-@pytest.mark.anyio
 async def test_server_reject_connection_with_response(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1034,7 +970,6 @@ async def test_server_reject_connection_with_response(
     assert disconnected_message == {"type": "websocket.disconnect", "code": 1006}
 
 
-@pytest.mark.anyio
 async def test_server_reject_connection_with_multibody_response(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1087,7 +1022,6 @@ async def test_server_reject_connection_with_multibody_response(
     assert disconnected_message == {"type": "websocket.disconnect", "code": 1006}
 
 
-@pytest.mark.anyio
 async def test_server_reject_connection_with_invalid_status(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1129,7 +1063,6 @@ async def test_server_reject_connection_with_invalid_status(
         await websocket_session(f"ws://127.0.0.1:{unused_tcp_port}")
 
 
-@pytest.mark.anyio
 async def test_server_reject_connection_with_body_nolength(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1174,7 +1107,6 @@ async def test_server_reject_connection_with_body_nolength(
         await websocket_session(f"ws://127.0.0.1:{unused_tcp_port}")
 
 
-@pytest.mark.anyio
 async def test_server_reject_connection_with_invalid_msg(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1212,7 +1144,6 @@ async def test_server_reject_connection_with_invalid_msg(
         await websocket_session(f"ws://127.0.0.1:{unused_tcp_port}")
 
 
-@pytest.mark.anyio
 async def test_server_reject_connection_with_missing_body(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1249,7 +1180,6 @@ async def test_server_reject_connection_with_missing_body(
         await websocket_session(f"ws://127.0.0.1:{unused_tcp_port}")
 
 
-@pytest.mark.anyio
 async def test_server_multiple_websocket_http_response_start_events(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1257,7 +1187,7 @@ async def test_server_multiple_websocket_http_response_start_events(
     The server should raise an exception if it sends multiple
     websocket.http.response.start events.
     """
-    exception_message: typing.Optional[str] = None
+    exception_message: str | None = None
 
     async def app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         nonlocal exception_message
@@ -1297,12 +1227,10 @@ async def test_server_multiple_websocket_http_response_start_events(
         await websocket_session(f"ws://127.0.0.1:{unused_tcp_port}")
 
     assert exception_message == (
-        "Expected ASGI message 'websocket.http.response.body' but got "
-        "'websocket.http.response.start'."
+        "Expected ASGI message 'websocket.http.response.body' but got " "'websocket.http.response.start'."
     )
 
 
-@pytest.mark.anyio
 async def test_server_can_read_messages_in_buffer_after_close(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1341,10 +1269,9 @@ async def test_server_can_read_messages_in_buffer_after_close(
         await send_text(f"ws://127.0.0.1:{unused_tcp_port}")
 
     assert frames == [b"abc", b"abc", b"abc"]
-    assert disconnect_message == {"type": "websocket.disconnect", "code": 1000}
+    assert disconnect_message == {"type": "websocket.disconnect", "code": 1000, "reason": ""}
 
 
-@pytest.mark.anyio
 async def test_default_server_headers(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1368,10 +1295,7 @@ async def test_default_server_headers(
         assert headers.get("server") == "uvicorn" and "date" in headers
 
 
-@pytest.mark.anyio
-async def test_no_server_headers(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_no_server_headers(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     class App(WebSocketResponse):
         async def websocket_connect(self, message):
             await self.send({"type": "websocket.accept"})
@@ -1393,11 +1317,8 @@ async def test_no_server_headers(
         assert "server" not in headers
 
 
-@pytest.mark.anyio
 @skip_if_no_wsproto
-async def test_no_date_header_on_wsproto(
-    http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_no_date_header_on_wsproto(http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     class App(WebSocketResponse):
         async def websocket_connect(self, message):
             await self.send({"type": "websocket.accept"})
@@ -1419,7 +1340,6 @@ async def test_no_date_header_on_wsproto(
         assert "date" not in headers
 
 
-@pytest.mark.anyio
 async def test_multiple_server_header(
     ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
 ):
@@ -1451,10 +1371,7 @@ async def test_multiple_server_header(
         assert headers.get_all("Server") == ["uvicorn", "over-ridden", "another-value"]
 
 
-@pytest.mark.anyio
-async def test_lifespan_state(
-    ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int
-):
+async def test_lifespan_state(ws_protocol_cls: WSProtocol, http_protocol_cls: HTTPProtocol, unused_tcp_port: int):
     expected_states = [
         {"a": 123, "b": [1]},
         {"a": 123, "b": [1, 2]},
@@ -1462,9 +1379,7 @@ async def test_lifespan_state(
 
     actual_states = []
 
-    async def lifespan_app(
-        scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable
-    ):
+    async def lifespan_app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         message = await receive()
         assert message["type"] == "lifespan.startup" and "state" in scope
         scope["state"]["a"] = 123
@@ -1485,9 +1400,7 @@ async def test_lifespan_state(
         async with websockets.client.connect(url) as websocket:
             return websocket.open
 
-    async def app_wrapper(
-        scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable
-    ):
+    async def app_wrapper(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable):
         if scope["type"] == "lifespan":
             return await lifespan_app(scope, receive, send)
         return await App(scope, receive, send)
